## 影院每日票房

接口：bo_cinema

描述：获取每日各影院的票房数据

数据历史： 数据从2018年9月开始，更多历史数据正在补充

数据权限：用户需要至少500积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期(格式:YYYYMMDD) |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| c_name | str | Y | 影院名称 |
| aud_count | int | Y | 观众人数 |
| att_ratio | float | Y | 上座率 |
| day_amount | float | Y | 当日票房 |
| day_showcount | float | Y | 当日场次 |
| avg_price | float | Y | 场均票价（元） |
| p_pc | float | Y | 场均人次 |
| rank | int | Y | 排名 |

接口使用

```python
pro = ts.pro_api()
#或者
#pro = ts.pro_api('your token')

df = pro.bo_cinema(date='20181014')
```

数据示例

```python
date        c_name                aud_count  att_ratio  day_amount  \
0   20181014    Jackie Chan北京耀莱        4973      20.70   215721.00   
```